@@ -1,4 +1,6 @@
 #!/usr/bin/env python
+from __future__ import print_function
+
 import sys, os, datetime, time, shutil, tempfile, subprocess, os.path
 from optparse import OptionParser
 from ._backup import *
@@ -7,30 +9,30 @@ info = "'rethinkdb dump' creates an archive of data from a RethinkDB cluster"
 usage = "rethinkdb dump [-c HOST:PORT] [-a AUTH_KEY] [-f FILE] [--clients NUM] [-e (DB | DB.TABLE)]..."
 
 def print_dump_help():
-    print info
-    print usage
-    print ""
-    print "  -h [ --help ]                    print this help"
-    print "  -c [ --connect ] HOST:PORT       host and client port of a rethinkdb node to connect"
-    print "                                   to (defaults to localhost:28015)"
-    print "  -a [ --auth ] AUTH_KEY           authorization key for rethinkdb clients"
-    print "  -f [ --file ] FILE               file to write archive to (defaults to"
-    print "                                   rethinkdb_dump_DATE_TIME.tar.gz)"
-    print "  -e [ --export ] (DB | DB.TABLE)  limit dump to the given database or table (may"
-    print "                                   be specified multiple times)"
-    print "  --clients NUM_CLIENTS            number of tables to export simultaneously (defaults"
-    print "                                   to 3)"
-    print "  --temp-dir DIRECTORY             the directory to use for intermediary results"
-    print ""
-    print "EXAMPLES:"
-    print "rethinkdb dump -c mnemosyne:39500"
-    print "  Archive all data from a cluster running on host 'mnemosyne' with a client port at 39500."
-    print ""
-    print "rethinkdb dump -e test -f rdb_dump.tar.gz"
-    print "  Archive only the 'test' database from a local cluster into a named file."
-    print ""
-    print "rethinkdb dump -c hades -e test.subscribers -a hunter2"
-    print "  Archive a specific table from a cluster running on host 'hades' which requires authorization."
+    print(info)
+    print(usage)
+    print("")
+    print("  -h [ --help ]                    print this help")
+    print("  -c [ --connect ] HOST:PORT       host and client port of a rethinkdb node to connect")
+    print("                                   to (defaults to localhost:28015)")
+    print("  -a [ --auth ] AUTH_KEY           authorization key for rethinkdb clients")
+    print("  -f [ --file ] FILE               file to write archive to (defaults to")
+    print("                                   rethinkdb_dump_DATE_TIME.tar.gz)")
+    print("  -e [ --export ] (DB | DB.TABLE)  limit dump to the given database or table (may")
+    print("                                   be specified multiple times)")
+    print("  --clients NUM_CLIENTS            number of tables to export simultaneously (defaults")
+    print("                                   to 3)")
+    print("  --temp-dir DIRECTORY             the directory to use for intermediary results")
+    print("")
+    print("EXAMPLES:")
+    print("rethinkdb dump -c mnemosyne:39500")
+    print("  Archive all data from a cluster running on host 'mnemosyne' with a client port at 39500.")
+    print("")
+    print("rethinkdb dump -e test -f rdb_dump.tar.gz")
+    print("  Archive only the 'test' database from a local cluster into a named file.")
+    print("")
+    print("rethinkdb dump -c hades -e test.subscribers -a hunter2")
+    print("  Archive a specific table from a cluster running on host 'hades' which requires authorization.")
 
 def parse_options():
     parser = OptionParser(add_help_option=False, usage=usage)
@@ -53,7 +55,7 @@ def parse_options():
         print_dump_help()
         exit(0)
 
-    res = { }
+    res = {}
 
     # Verify valid host:port --connect option
     (res["host"], res["port"]) = parse_connect_option(options.host)
@@ -70,7 +72,7 @@ def parse_options():
 
     # Verify valid client count
     if options.clients < 1:
-       raise RuntimeError("Error: invalid number of clients (%d), must be greater than zero" % options.clients)
+        raise RuntimeError("Error: invalid number of clients (%d), must be greater than zero" % options.clients)
     res["clients"] = options.clients
 
     # Make sure the temporary directory exists and is accessible
@@ -88,7 +90,7 @@ def parse_options():
     return res
 
 def do_export(temp_dir, options):
-    print "Exporting to directory..."
+    print("Exporting to directory...")
     export_args = ["rethinkdb-export"]
     export_args.extend(["--connect", "%s:%s" % (options["host"], options["port"])])
     export_args.extend(["--directory", os.path.join(temp_dir, options["temp_filename"])])
@@ -108,7 +110,7 @@ def do_export(temp_dir, options):
     # 'Done' message will be printed by the export script
 
 def do_zip(temp_dir, options):
-    print "Zipping export directory..."
+    print("Zipping export directory...")
     start_time = time.time()
     tar_args = ["tar", "czf", options["out_file"]]
 
@@ -121,7 +123,7 @@ def do_zip(temp_dir, options):
     res = subprocess.call(tar_args)
     if res != 0:
         raise RuntimeError("Error: tar of export directory failed")
-    print "  Done (%d seconds)" % (time.time() - start_time)
+    print("  Done (%d seconds)" % (time.time() - start_time))
 
 def run_rethinkdb_export(options):
     # Create a temporary directory to store the intermediary results
@@ -129,9 +131,9 @@ def run_rethinkdb_export(options):
     res = -1
 
     # Print a warning about the capabilities of dump, so no one is confused (hopefully)
-    print "NOTE: 'rethinkdb-dump' only dumps data and does *not* dump secondary indexes or"
-    print " cluster metadata.  You will need to recreate your secondary indexes and cluster"
-    print " setup yourself after you run 'rethinkdb-restore'."
+    print("NOTE: 'rethinkdb-dump' only dumps data and does *not* dump secondary indexes or")
+    print(" cluster metadata.  You will need to recreate your secondary indexes and cluster")
+    print(" setup yourself after you run 'rethinkdb-restore'.")
 
     try:
         do_export(temp_dir, options)
@@ -146,15 +148,15 @@ def main():
     try:
         options = parse_options()
     except RuntimeError as ex:
-        print >> sys.stderr, "Usage: %s" % usage
-        print >> sys.stderr, ex
+        print("Usage: %s" % usage, file=sys.stderr)
+        print(ex, file=sys.stderr)
         return 1
 
     try:
         start_time = time.time()
         run_rethinkdb_export(options)
     except RuntimeError as ex:
-        print >> sys.stderr, ex
+        print(ex, file=sys.stderr)
         return 1
     return 0
 
