@@ -56,7 +56,7 @@ def expr(val, nesting_depth=20):
         return MakeObj(obj)
     elif isinstance(val, collections.Callable):
         return Func(val)
-    elif isinstance(val, datetime.datetime) or isinstance(val, datetime.date):
+    elif isinstance(val, (datetime.datetime, datetime.date)):
         if not hasattr(val, 'tzinfo') or not val.tzinfo:
             raise RqlDriverError("""Cannot convert %s to ReQL time object
             without timezone information. You can add timezone information with
@@ -82,8 +82,6 @@ class RqlQuery(object):
 
         self.optargs = {}
         for k, v in dict_items(optargs):
-            if not isinstance(v, RqlQuery) and v == ():
-                continue
             self.optargs[k] = expr(v)
 
     # Send this query to the server to be executed
@@ -272,20 +270,12 @@ class RqlQuery(object):
         return Default(self, *args)
 
     def update(self, *args, **kwargs):
-        kwargs.setdefault('non_atomic', ())
-        kwargs.setdefault('durability', ())
-        kwargs.setdefault('return_changes', ())
         return Update(self, *[func_wrap(arg) for arg in args], **kwargs)
 
     def replace(self, *args, **kwargs):
-        kwargs.setdefault('non_atomic', ())
-        kwargs.setdefault('durability', ())
-        kwargs.setdefault('return_changes', ())
         return Replace(self, *[func_wrap(arg) for arg in args], **kwargs)
 
     def delete(self, *args, **kwargs):
-        kwargs.setdefault('durability', ())
-        kwargs.setdefault('return_changes', ())
         return Delete(self, *args, **kwargs)
 
     # Rql type inspection
@@ -330,19 +320,8 @@ class RqlQuery(object):
                 return Slice(self, index.start or 0, index.stop, bracket_operator=True)
             else:
                 return Slice(self, index.start or 0, -1, right_bound='closed', bracket_operator=True)
-        elif isinstance(index, int):
-            return Nth(self, index, bracket_operator=True)
-        elif isinstance(index, (str, unicode)):
-            return GetField(self, index, bracket_operator=True)
-        elif isinstance(index, RqlQuery):
-            raise RqlDriverError(
-                "Bracket operator called with a ReQL expression parameter.\n"+
-                "Dynamic typing is not supported in this syntax,\n"+
-                "use `.nth`, `.slice`, or `.get_field` instead.")
         else:
-            raise RqlDriverError(
-                "bracket operator called with an unsupported parameter type: %s.%s" %
-                (index.__class__.__module__, index.__class__.__name__))
+            return Bracket(self, index, bracket_operator=True)
 
     def __iter__(*args, **kwargs):
         raise RqlDriverError(
@@ -402,20 +381,16 @@ class RqlQuery(object):
         return Map(self, *[func_wrap(arg) for arg in args])
 
     def filter(self, *args, **kwargs):
-        kwargs.setdefault('default', ())
         return Filter(self, *[func_wrap(arg) for arg in args], **kwargs)
 
     def concat_map(self, *args):
         return ConcatMap(self, *[func_wrap(arg) for arg in args])
 
     def order_by(self, *args, **kwargs):
-        args = [arg if isinstance(arg, Asc) or isinstance(arg, Desc) else func_wrap(arg) for arg in args]
+        args = [arg if isinstance(arg, (Asc, Desc)) else func_wrap(arg) for arg in args]
         return OrderBy(self, *args, **kwargs)
 
     def between(self, *args, **kwargs):
-        kwargs.setdefault('left_bound', ())
-        kwargs.setdefault('right_bound', ())
-        kwargs.setdefault('index', ())
         return Between(self, *args, **kwargs)
 
     def distinct(self, *args, **kwargs):
@@ -436,7 +411,6 @@ class RqlQuery(object):
         return OuterJoin(self, *args)
 
     def eq_join(self, *args, **kwargs):
-        kwargs.setdefault('index', ())
         return EqJoin(self, *[func_wrap(arg) for arg in args], **kwargs)
 
     def zip(self, *args):
@@ -476,8 +450,6 @@ class RqlQuery(object):
         return ToEpochTime(self, *args)
 
     def during(self, *args, **kwargs):
-        kwargs.setdefault('left_bound', ())
-        kwargs.setdefault('right_bound', ())
         return During(self, *args, **kwargs)
 
     def date(self, *args):
@@ -516,10 +488,30 @@ class RqlQuery(object):
     def in_timezone(self, *args):
         return InTimezone(self, *args)
 
+    ## Geospatial support
+
+    def to_geojson(self, *args):
+        return ToGeoJson(self, *args)
+
+    def distance(self, *args, **kwargs):
+        return Distance(self, *args, **kwargs)
+
+    def intersects(self, *args):
+        return Intersects(self, *args)
+
+    def includes(self, *args):
+        return Includes(self, *args)
+
+    def fill(self, *args):
+        return Fill(self, *args)
+
+    def polygon_sub(self, *args):
+        return PolygonSub(self, *args)
+
 # These classes define how nodes are printed by overloading `compose`
 
 def needs_wrap(arg):
-    return isinstance(arg, Datum) or isinstance(arg, MakeArray) or isinstance(arg, MakeObj)
+    return isinstance(arg, (Datum, MakeArray, MakeObj))
 
 class RqlBoolOperQuery(RqlQuery):
     def __init__(self, *args, **optargs):
@@ -667,6 +659,9 @@ def convert_pseudotype(obj, format_opts):
                 return reql_type_grouped_data_to_object(obj)
             elif group_format != 'raw':
                 raise RqlDriverError("Unknown group_format run option \"%s\"." % group_format)
+        elif reql_type == 'GEOMETRY':
+            # No special support for this. Just return the raw object
+            return obj
         elif reql_type == 'BINARY':
             binary_format = format_opts.get('binary_format')
             if binary_format is None or binary_format == 'native':
@@ -775,6 +770,9 @@ class Default(RqlMethodQuery):
 class ImplicitVar(RqlQuery):
     tt = pTerm.IMPLICIT_VAR
 
+    def __call__(self, *args, **kwargs):
+        raise TypeError("'r.row' is not callable, use 'r.row[...]' instead")
+
     def compose(self, args, optargs):
         return 'r.row'
 
@@ -883,6 +881,10 @@ class GetField(RqlBracketQuery):
     tt = pTerm.GET_FIELD
     st = 'get_field'
 
+class Bracket(RqlBracketQuery):
+    tt = pTerm.BRACKET
+    st = 'bracket'
+
 class Contains(RqlMethodQuery):
     tt = pTerm.CONTAINS
     st = 'contains'
@@ -927,16 +929,12 @@ class DB(RqlTopLevelQuery):
         return TableList(self, *args)
 
     def table_create(self, *args, **kwargs):
-        kwargs.setdefault('primary_key', ())
-        kwargs.setdefault('datacenter', ())
-        kwargs.setdefault('durability', ())
         return TableCreate(self, *args, **kwargs)
 
     def table_drop(self, *args):
         return TableDrop(self, *args)
 
     def table(self, *args, **kwargs):
-        kwargs.setdefault('use_outdated', ())
         return Table(self, *args, **kwargs)
 
 class FunCall(RqlQuery):
@@ -966,9 +964,6 @@ class Table(RqlQuery):
     st = 'table'
 
     def insert(self, *args, **kwargs):
-        kwargs.setdefault('conflict', ())
-        kwargs.setdefault('durability', ())
-        kwargs.setdefault('return_changes', ())
         return Insert(self, *[expr(arg) for arg in args], **kwargs)
 
     def get(self, *args):
@@ -978,7 +973,6 @@ class Table(RqlQuery):
         return GetAll(self, *args, **kwargs)
 
     def index_create(self, *args, **kwargs):
-        kwargs.setdefault('multi', ())
         if len(args) > 1:
             args = [args[0]] + [func_wrap(arg) for arg in args[1:]]
         return IndexCreate(self, *args, **kwargs)
@@ -1001,6 +995,15 @@ class Table(RqlQuery):
     def sync(self, *args):
         return Sync(self, *args)
 
+    def get_intersecting(self, *args, **kwargs):
+        return GetIntersecting(self, *args, **kwargs)
+
+    def get_nearest(self, *args, **kwargs):
+        return GetNearest(self, *args, **kwargs)
+
+    def uuid(self, *args, **kwargs):
+        return UUID(self, *args, **kwargs)
+
     def compose(self, args, optargs):
         if isinstance(self.args[0], DB):
             return T(args[0], '.table(', T(*(args[1:]), intsp=', '), ')')
@@ -1015,6 +1018,18 @@ class GetAll(RqlMethodQuery):
     tt = pTerm.GET_ALL
     st = 'get_all'
 
+class GetIntersecting(RqlMethodQuery):
+    tt = pTerm.GET_INTERSECTING
+    st = 'get_intersecting'
+
+class GetNearest(RqlMethodQuery):
+    tt = pTerm.GET_NEAREST
+    st = 'get_nearest'
+
+class UUID(RqlMethodQuery):
+    tt = pTerm.UUID
+    st = 'uuid'
+
 class Reduce(RqlMethodQuery):
     tt = pTerm.REDUCE
     st = 'reduce'
@@ -1377,6 +1392,50 @@ class ToEpochTime(RqlMethodQuery):
     tt = pTerm.TO_EPOCH_TIME
     st = 'to_epoch_time'
 
+class GeoJson(RqlTopLevelQuery):
+    tt = pTerm.GEOJSON
+    st = 'geojson'
+
+class ToGeoJson(RqlMethodQuery):
+    tt = pTerm.TO_GEOJSON
+    st = 'to_geojson'
+
+class Point(RqlTopLevelQuery):
+    tt = pTerm.POINT
+    st = 'point'
+
+class Line(RqlTopLevelQuery):
+    tt = pTerm.LINE
+    st = 'line'
+
+class Polygon(RqlTopLevelQuery):
+    tt = pTerm.POLYGON
+    st = 'polygon'
+
+class Distance(RqlMethodQuery):
+    tt = pTerm.DISTANCE
+    st = 'distance'
+
+class Intersects(RqlMethodQuery):
+    tt = pTerm.INTERSECTS
+    st = 'intersects'
+
+class Includes(RqlMethodQuery):
+    tt = pTerm.INCLUDES
+    st = 'includes'
+
+class Circle(RqlTopLevelQuery):
+    tt = pTerm.CIRCLE
+    st = 'circle'
+
+class Fill(RqlMethodQuery):
+    tt = pTerm.FILL
+    st = 'fill'
+
+class PolygonSub(RqlMethodQuery):
+    tt = pTerm.POLYGON_SUB
+    st = 'polygon_sub'
+
 # Returns True if IMPLICIT_VAR is found in the subquery
 def _ivar_scan(query):
     if not isinstance(query, RqlQuery):
